import React from 'react';
import { render, screen, waitFor } from '@/test-utils/index';
import { NsAutocomplete } from '@/common/index';
import { OptionUiComponent } from './mock/MockUI';
import { AutocompleteMockList } from './mock/MockData';
import userEvent from '@testing-library/user-event';
import { act } from 'react-dom/test-utils';

describe('CustomAutocomplete', () => {
    it('1. should render autocomplete component', () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                placeholder="autocomplete-input"
                OptionsUI={OptionUiComponent}
                inputValue=""
                value=""
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
    });
    it('2. check that onChange gets called', () => {
        const onSelectMock = jest.fn();
        const onChangeMock = jest.fn();
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                onSelect={onSelectMock}
                onChange={onChangeMock}
                placeholder="autocomplete-input"
                OptionsUI={OptionUiComponent}
                inputValue=""
                value=""
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        expect(onChangeMock).toHaveBeenCalled();
    });

    it('3. displays options when typing in the input', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                onSelect={() => {}}
                OptionsUI={OptionUiComponent}
                placeholder="autocomplete-input"
                inputValue=""
                value=""
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(
            () => {
                const option1 = screen.getByText('GS Facial Gels 2pk Subscription');
                expect(option1).toBeInTheDocument();
            },
            { timeout: 5000 }
        );
    }, 40000);

    it('4. selects an option when clicking on it', async () => {
        const onSelectMock = jest.fn();
        render(
            <NsAutocomplete
                onSelect={onSelectMock}
                options={AutocompleteMockList}
                OptionsUI={OptionUiComponent}
                placeholder="autocomplete-input"
                inputValue=""
                value=""
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(() => {
            const optionLi = screen.getByText('GS Facial Spa');
            userEvent.click(optionLi);
        });
        expect(onSelectMock).toHaveBeenCalled();
    }, 40000);

    it('5. should load more options when clicking load more button', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                OptionsUI={OptionUiComponent}
                placeholder="autocomplete-input"
                seeMore={{
                    text: '',
                    show: true,
                    onSeeMore: () => ({}),
                }}
                inputValue=""
                value=""
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(() => {
            const loadMoreButton = screen.getByTestId('autocomplete-loadmore-id');
            userEvent.click(loadMoreButton);
        });
    }, 40000);

    it('6. should clear options when clicking clear button', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                OptionsUI={OptionUiComponent}
                placeholder="autocomplete-input"
                clear={{
                    text: '',
                    show: true,
                    onClear: () => ({}),
                }}
                inputValue=""
                value=""
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(() => {
            const clearButton = screen.getByTestId('autocomplete-clear-id');
            userEvent.click(clearButton);
        });
    }, 40000);
});
