import { Button as MUIButton } from '@mui/material';

import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { ButtonConfig } from '@nuskin/foundation-theme/src/common/themes/types/button';

import { NsButtonProps } from './types.d';
import { generateContainedStyle, generateIconOnlyStyles, generateOutlinedStyle, generateTextStyles } from './helper';
import { skipDarkModeEnabled } from '../util';

const { buttonColor, paletteColor } = ColorUtils;

const getButtonConfig = (theme: FoundationTheme.Theme, attribute: keyof ButtonConfig) => {
    const { config } = theme || {};
    return config?.components?.button?.[attribute] || '';
};
const options = {
    shouldForwardProp: skipDarkModeEnabled,
};
const StyledButton = styled(MUIButton, options)<NsButtonProps>`
    gap: 10px;
    border-radius: ${({ theme }) => {
        const borderRadius = getButtonConfig(theme, 'borderRadius');
        return borderRadius || 0;
    }};

    &:focus {
        border: 1px solid ${({ theme }) => getButtonConfig(theme, 'focusColor')} !important;
    }

    &:disabled {
        background-color: ${({ color }) => buttonColor(color, 'disabled')};
        color: ${({ color }) => buttonColor(color, 'disabledText')};
    }

    ${({ theme: { config }, size }) => {
        if (size === 'medium') {
            return config?.components?.button?.size?.medium?.padding;
        } else if (size === 'large') {
            return config?.components?.button?.size?.large?.padding;
        } else {
            return '';
        }
    }}

    ${({ variant, theme, color = 'primary', darkModeEnabled, iconOnly }) => {
        if (variant === 'contained') {
            const hovered = buttonColor(color, 'hovered')({ theme });
            const pressed = buttonColor(color, 'pressed')({ theme });
            const focused = buttonColor(color, 'focused')({ theme });
            const textColor = paletteColor(color, 'contrastText')({ theme, darkModeEnabled });
            const backgroundColor = paletteColor(color)({ theme, darkModeEnabled });
            return generateContainedStyle({ backgroundColor, textColor, hovered, pressed, focused });
        } else if (variant === 'outlined') {
            const borderColor = paletteColor(color)({ theme, darkModeEnabled });
            const activeColor = paletteColor(color)({ theme });
            const hovered = buttonColor(color, 'hovered')({ theme });
            const pressed = buttonColor(color, 'pressed')({ theme });
            return generateOutlinedStyle({ borderColor, hovered, pressed, activeColor });
        } else if (variant === 'text') {
            const underlineColor = paletteColor(color)({ theme, darkModeEnabled });
            const hovered = buttonColor(color, 'hovered')({ theme });
            const pressed = buttonColor(color, 'pressed')({ theme });
            return generateTextStyles({ underlineColor, hovered, pressed });
        } else if (iconOnly) {
            return generateIconOnlyStyles();
        } else {
            return '';
        }
    }}
`;

export default StyledButton;
