import { render, screen, fireEvent } from '@testing-library/react';
import NsFfgCard from '../NsFfgCard';

describe('NsFfgCard component', () => {
    const props = {
        topImageUrl: 'https://media.nuskin.com/m/6245528b8f76ad32/webimage-brand-ageLOC.png',
        topImageAlt: 'alt-text',
        text: 'card text',
        cardLink: { href: 'https://www.google.com', title: 'Test' },
        onClick: jest.fn(),
    };
    it('1. renders with background image', () => {
        render(<NsFfgCard {...props} additionalProps={{ testid: 'ffg-card' }} />);
        const card = screen.getByTestId('ffg-card');
        expect(card).toHaveStyle(`
          background-color: #fff;
        `);
    });
    it('2. renders with cover size', () => {
        render(<NsFfgCard {...props} additionalProps={{ testid: 'ffg-card-1' }} />);
        const card = screen.getByText(props.cardLink.title);
        expect(card).toBeInTheDocument();
    });
    it('3. calls onclick', () => {
        const handler = jest.fn();
        const { getByTestId } = render(
            <NsFfgCard {...props} onClick={handler} additionalProps={{ testid: 'ffg-card-1' }} />
        );
        const card = getByTestId('ffg-card-1');
        fireEvent.click(card);
        expect(handler).toHaveBeenCalled();
    });
});
