import type { StoryObj, Meta } from '@storybook/react';
import { within, userEvent } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsFfgCard } from '../';

type ComponentType = typeof NsFfgCard;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsFfgCard,
    title: 'Components/Containers/Card/NsFfgCard',
    argTypes: {
        onClick: {
            action: 'clicked',
        },
    },
    decorators: [withCenterDecorator],
} as MetaStory;

const text = `Every child deserves a chance to shine. Through our Nu Skin Force for Good Foundation,
 we’re empowering children around the world with hope for a brighter future.`;
const host = 'https://images.contentstack.io/v3/assets';

export const Default: Story = {
    args: {
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'LEARN MORE',
        },
        text,
        topImageUrl: `${host}/blt594f30e2dc643eae/blt34cdb300dc9b93ff/645ccaa7520ba1a1af13a08a/nsffg-foundation.webp`,
        topImageAlt: 'Force for Good Foundation',
        additionalProps: {
            testid: 'ffg-card',
        },
        onClick: () => {
            console.log('onClick called');
        },
    },
    play: async ({ canvasElement }: any) => {
        const canvas = within(canvasElement);
        userEvent.hover(canvas.getByTestId('ffg-card'));
        userEvent.hover(canvas.getByRole('link'));
        expect(canvas.getByText(text)).toBeInTheDocument();
    },
};
const d = { count: -1 };
export const OnClick: Story = {
    args: {
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'LEARN MORE',
        },
        text,
        topImageUrl: `${host}/blt594f30e2dc643eae/blt34cdb300dc9b93ff/645ccaa7520ba1a1af13a08a/nsffg-foundation.webp`,
        topImageAlt: 'Force for Good Foundation',
        additionalProps: {
            testid: 'ffg-card',
        },
        onClick: () => {
            d.count = 1;
            console.log('on click called');
        },
    },
    play: async ({ canvasElement }: any) => {
        d.count = 0;
        const canvas = within(canvasElement);
        userEvent.click(canvas.getByTestId('ffg-card'));
        expect(d.count).toEqual(1);
    },
};
