import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { Themed } from '../common.types';
import { getDropdownHeadBorder } from '../dropdown/NsDropdown.styled';
const { color, paletteColor, isDarkMode } = ColorUtils;

export const SelectContainer = styled.div<{ disabled: boolean }>`
    position: relative;
    display: inline-block;
    opacity: ${({ disabled }) => (disabled ? '0.5' : '1')};
`;

export const SelectHead = styled.div<{ type: string; disabled: boolean }>`
    cursor: ${({ disabled }) => (disabled ? 'inherit' : 'pointer')};
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    border: ${getDropdownHeadBorder}
    color: ${paletteColor('primary')};
    width: 207px;
    position: relative;
    z-index: 2;
`;

export const SelectButton = styled.div`
    padding-right: 10px;
`;

export const SelectList = styled.div<{ borderColor: FoundationTheme.PaletteColors }>`
    position: absolute;
    z-index: 100;
    border: 1px solid ${({ borderColor, theme }) => paletteColor(borderColor)({ theme })};
    padding: 0;
    margin: 0;
    width: -webkit-fill-available;
    color: ${paletteColor('primary')};
    background-color: ${paletteColor('primary', 'contrastText')};
`;

const getDividerColor = (props: { theme: FoundationTheme.Theme }) => {
    return !isDarkMode(props) ? color('neutral', '30')(props) : color('neutral', '20')(props);
};

const getListBgColor = (props: { theme: FoundationTheme.Theme }) => {
    return !isDarkMode(props) ? color('accentColorB', '10')(props) : color('accentColorB', '50')(props);
};
type ContainerParam = { borderBottom: string; bgColor: string; color: string; hoveredBg: string };
function createListContainerStyle({ borderBottom, bgColor, color, hoveredBg }: ContainerParam) {
    return `
    cursor: pointer;
    padding: 5px 0;
    border-bottom: 1px solid ${borderBottom};
    background-color: ${bgColor};
    color: ${color};

    &:hover {
        background-color: ${hoveredBg};
    }

    &:last-child {
        border-bottom: none;
    }
`;
}
export const ListItemContainer = styled.div<{ showListDivider: boolean; isSelected: boolean }>`
    ${({ showListDivider, isSelected, theme }) => {
        const borderBottom = showListDivider ? getDividerColor({ theme }) : 'none';
        const bgColor = isSelected ? paletteColor('primary')({ theme }) : 'white';
        const color = isSelected ? 'white' : 'black';
        const hoveredBg = getListBgColor({ theme });
        return createListContainerStyle({ borderBottom, bgColor, color, hoveredBg });
    }}
`;
const getListItemBgColor = ({ isSelected, theme }: { isSelected: boolean } & Themed) => {
    if (isSelected) {
        return paletteColor('primary')({ theme });
    }
    return getListBgColor({ theme });
};

const getListItemBorderLeftColor = ({ isSelected, theme }: { isSelected: boolean } & Themed) => {
    if (isSelected) {
        const color = paletteColor('primary')({ theme });
        return `2px solid ${color}`;
    }
    return 'none';
};

export const ListItem = styled.div<{ isSelected: boolean }>(({ isSelected, theme }) => ({
    padding: '5px 10px',
    borderLeft: getListItemBorderLeftColor({ isSelected, theme }),
    backgroundColor: isSelected ? paletteColor('primary', 'main')({ theme }) : 'white',
    color: isSelected ? 'white' : 'black',
    '&:hover': {
        backgroundColor: getListItemBgColor({ isSelected, theme }),
        fontWeight: 'bold',
    },
}));

export const SelectLabel = styled.label`
    display: block;
    margin-bottom: 5px;
    color: ${paletteColor('primary')} !important;
`;
